@@ -6,7 +6,7 @@
 """
 
 __author__ = "James Turk <jturk@sunlightfoundation.com>"
-__version__ = "0.3.1"
+__version__ = "0.3.2"
 __copyright__ = "Copyright (c) 2009 Sunlight Labs"
 __license__ = "BSD"
 
@@ -193,7 +193,8 @@ def _result_to_obj(cls, result):
     if isinstance(result, dict):
         return [cls(result)]
     else:
-        return [cls(o) for o in result]
+        # the if o predicate is important, sometimes they return empty strings
+        return [cls(o) for o in result if o]
 
 class votesmart(object):
 
